#include <stdio.h>
#include <sys/time.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <stdlib.h>
#include <time.h>

#include "data.h"

#define SYSFS_POSITION_FILE	"/sys/devices/platform/hdaps/position"
#define SYSFS_TEMP1_FILE	"/sys/devices/platform/hdaps/temp1"
#define SYSFS_TEMP2_FILE	"/sys/devices/platform/hdaps/temp2"
#define BUF_LEN			32

#ifdef TEMP
char* get_temp(int num)
{
	FILE *f;
	int t; 
	char *buffer;


	buffer = malloc(sizeof(char)*512);
	if ((f = fopen((!num)?SYSFS_TEMP1_FILE:SYSFS_TEMP2_FILE, "r")) == NULL) {
		sprintf(buffer, "APS: error");
		return(buffer);
	}
	fgets(buffer, 512, f);
	fclose(f);
	sscanf(buffer, "%d", &t);
	snprintf(buffer, 512, (!num)?"APS1 %d.0C":"APS2 %d.0C", t);

	return(buffer);
}
#endif

#ifdef PIVOT

static int rest_x;
static int rest_y;

char* get_pivot()
{
	char *buffer;
	int x, y;
	int ret;
	
	
	buffer = malloc(sizeof(char)*512);
	ret = read_position (&x, &y);
	if (ret) {
		sprintf(buffer, "TILT error");
	}
	else {
		sprintf(buffer, "TILT %d/%d", x - rest_x, y - rest_y);
	}
	return(buffer);
}

/*
 * pivot.c - read from the HDAPS (HardDrive Active Protection System).
 *
 * Copyright (C) 2005 Robert Love <rml@novell.com>
 *
 * "Why does that kid keep dropping his laptop?"
 */

/*
 * read_position - read the (x,y) position pair from hdaps.
 *
 * We open and close the file on every invocation, which is lame but due to
 * several features of sysfs files:
 *
 *	(a) Sysfs files are seekable.
 *	(b) Seeking to zero and then rereading does not seem to work.
 *
 * If I were king--and I will be one day--I would have made sysfs files
 * nonseekable and only able to return full-size reads.
 */
int read_position (int *x, int *y)
{
	char buf[BUF_LEN];
	int fd, ret;

	fd = open (SYSFS_POSITION_FILE, O_RDONLY);
	if (fd < 0) {
		perror ("open");
		return fd;
	}	

	ret = read (fd, buf, BUF_LEN);
	if (ret < 0) {
		perror ("read");
		goto out;
	} else if (ret == 0) {
		fprintf (stderr, "error: unexpectedly read zero!\n");
		ret = 1;
		goto out;
	}
	ret = 0;

	if (sscanf (buf, "(%d,%d)\n", x, y) != 2)
		ret = 1;

out:
	if (close (fd))
		perror ("close");

	return ret;
}

void init_pivot(void)
{
	int ret;

	/* get some base data for calibration */
	ret = read_position (&rest_x, &rest_y);
	if (ret)
		return;
	
	//printf ("(x,y) base: (%u,%u)\n", rest_x, rest_y);
/*
	for (i = 0; i < 1000; i++) {
		struct timespec ts = { 0, 250000000 };
		int x, y;

		ret = read_position (&x, &y);
		if (ret)
			break;

		printf ("(x,y) position: (%d,%d)\n", x - rest_x, y - rest_y);

		ret = nanosleep (&ts, NULL);
		if (ret) {
			perror ("nanosleep");
			break;
		}
	}

	return ret;
*/
}
#endif
